__version__ = '1.1.0'

__title__ = 'noora'
__description__ = 'NoOra a database deployment tool.'
__uri__ = 'https://github.com/janripke/noora'
__doc__ = __description__ + ' <' + __uri__ + '>'

__author__ = 'Jan Ripke'
__email__ = 'jan.ripke@oxyma.nl'

__license__ = 'GNU General Public License v3 or later (GPLv3+)'
__copyright__ = 'Copyleft (l) 2017 Jan Ripke'

